@@ -6,7 +6,7 @@ use warnings;
 use Text::Markup::Cmd;
 use utf8;
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 my $ASCIIDOC = find_cmd([
     (map { (WIN32 ? ("$_.exe", "$_.bat") : ($_)) } qw(asciidoc)),
@@ -39,7 +39,7 @@ sub parser {
     # Make sure we have something.
     return unless $html =~ /\S/;
     utf8::encode $html;
-    return $html if $opts->{raw};
+    return $html if { @{ $opts } }->{raw};
     return qq{<html>
 <head>
 <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
@@ -62,7 +62,10 @@ Text::Markup::Asciidoc - Asciidoc parser for Text::Markup
 
   use Text::Markup;
   my $html = Text::Markup->new->parse(file => 'hello.adoc');
-  my $raw_asciidoc = Text::Markup->new->parse(file => 'hello.adoc', raw => 1 );
+  my $raw = Text::Markup->new->parse(
+      file    => 'hello.adoc',
+      options => [raw => 1],
+  );
 
 =head1 Description
 
