@@ -6,16 +6,17 @@ use warnings;
 use File::BOM qw(open_bom);
 use Text::Markdown ();
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 sub parser {
     my ($file, $encoding, $opts) = @_;
-    my $md = Text::Markdown->new(@{ $opts || [] });
+    my %params = @{ $opts };
+    my $md = Text::Markdown->new(%params);
     open_bom my $fh, $file, ":encoding($encoding)";
     my $html = $md->markdown(join '', <$fh>);
     return unless $html =~ /\S/;
     utf8::encode($html);
-    return $html if $opts->{raw};
+    return $html if $params{raw};
     return qq{<html>
 <head>
 <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
@@ -38,7 +39,10 @@ Text::Markup::Markdown - Markdown parser for Text::Markup
 =head1 Synopsis
 
   my $html = Text::Markup->new->parse(file => 'README.md');
-  my $raw  = Text::Markup->new->parse(file => 'README.md', raw => 1);
+  my $raw  = Text::Markup->new->parse(
+      file    => 'README.md',
+      options => [ raw => 1 ],
+  );
 
 =head1 Description
 
@@ -69,6 +73,19 @@ Normally this module returns the output wrapped in a minimal HTML document
 skeleton. If you would like the raw output without the skeleton, you can pass
 the C<raw> option to C<parse>.
 
+In addition, Text::Markup::Markdown supports all of the
+L<Text::Markdown options|Text::Markdown/OPTIONS>, including:
+
+=over
+
+=item C<empty_element_suffix>
+
+=item C<tab_width>
+
+=item C<trust_list_start_value>
+
+=back
+
 =head1 See Also
 
 L<National Funk Congress Deadlocked On Get Up/Get Down Issue|https://www.theonion.com/national-funk-congress-deadlocked-on-get-up-get-down-is-1819565355>.
