@@ -6,17 +6,18 @@ use warnings;
 use File::BOM qw(open_bom);
 use Text::MultiMarkdown ();
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 sub parser {
     my ($file, $encoding, $opts) = @_;
-    my $md = Text::MultiMarkdown->new(@{ $opts || [] });
+    my %params = @{ $opts };
+    my $md = Text::MultiMarkdown->new(%params);
     open_bom my $fh, $file, ":encoding($encoding)";
     local $/;
     my $html = $md->markdown(<$fh>);
     return unless $html =~ /\S/;
     utf8::encode($html);
-    return $html if $opts->{raw};
+    return $html if $params{raw};
     return qq{<html>
 <head>
 <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
@@ -38,8 +39,11 @@ Text::Markup::Multimarkdown - MultiMarkdown parser for Text::Markup
 
 =head1 Synopsis
 
-  my $html = Text::Markup->new->parse(file => 'README.md');
-  my $raw  = Text::Markup->new->parse(file => 'README.md', raw => 1);
+  my $html = Text::Markup->new->parse(file => 'README.mmd');
+  my $raw  = Text::Markup->new->parse(
+      file    => 'README.mmd',
+      options => [ raw => 1 ],
+  );
 
 =head1 Description
 
@@ -68,7 +72,36 @@ It recognizes files with the following extensions as MultiMarkdown:
 
 Normally this module returns the output wrapped in a minimal HTML document
 skeleton. If you would like the raw output without the skeleton, you can pass
-the C<raw> option to C<parse>.
+the C<raw> option to the format options argument to C<parse>.
+
+In addition, Text::Markup::Mediawiki supports all of the
+L<Text::MultiMarkdown options|Text::MultiMarkdown/OPTIONS>, including:
+
+=over
+
+=item C<use_metadata>
+
+=item C<strip_metadata>
+
+=item C<empty_element_suffix>
+
+=item C<img_ids>
+
+=item C<heading_ids>
+
+=item C<bibliography_title>
+
+=item C<tab_width>
+
+=item C<disable_tables>
+
+=item C<disable_footnotes>
+
+=item C<disable_bibliography>
+
+=item C<disable_definition_lists>
+
+=back
 
 =head1 Author
 
